@@ -1,7 +1,7 @@
 import requests
 import json
 from . import api
-from data import *
+from codeanalyst.data import *
 url = api
 
 def codetest(code, lang, langv = "None", cid = "2c1d7916a28c2ac644a6acb7abdf8847", secret = "36a72c45e217e3097fded87023f138722beaedc1b345ad50e3f7094ff9145548"):
